@@ -36,6 +36,12 @@
 #include <assert.h>
 #endif
 
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+#ifdef HAVE_NETINET6_IN6_H
+#include <netinet6/in6.h>
+#endif
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
@@ -44,3 +50,4 @@
 #endif
 
 #include <clib/clib.h>
+#include <clib/rbtree.h>
